Learn R Programming

cayleyR (version 0.2.1)

check_duplicates: Find Duplicate States Between Two Tables

Description

Identifies states that appear in both tables by comparing V-columns. Used for finding intersections between forward and backward searches.

Usage

check_duplicates(df1, df2)

Value

Data frame of duplicate states with a source column, or NULL if none

Arguments

df1

Data frame (first set of states)

df2

Data frame (second set of states)

Examples

Run this code
df1 <- data.frame(V1 = c(1, 2), V2 = c(2, 1))
df2 <- data.frame(V1 = c(2, 3), V2 = c(1, 2))
check_duplicates(df1, df2)

Run the code above in your browser using DataLab