powered by
For each combination in a data frame of top results, runs a full cycle analysis and collects all states with their celestial coordinates into a single data frame.
analyze_top_combinations(top_combos, start_state, k)
Data frame with columns V1..Vn, operation, step, combo_number, nL, nR, nX, theta, phi, omega_conformal
Data frame or data.table with a combination column (string of operation digits, e.g., "132")
combination
Integer vector, the initial permutation state
Integer, parameter for reverse operations
combos <- data.frame(combination = c("13", "23"), stringsAsFactors = FALSE) # result <- analyze_top_combinations(combos, 1:10, k = 4)
Run the code above in your browser using DataLab