powered by
Applies a sequence of permutation operations to multiple states simultaneously using matrix multiplication on the Vulkan backend.
apply_operations_batch_gpu(states_matrix, operations, k)
Numeric matrix (nrow x n) with transformed states
Numeric matrix (nrow x n), each row is a state
Character vector of operation codes (e.g., c("L", "R", "X"))
Integer, parameter for reverse operations
# \donttest{ if (cayley_gpu_available()) { mat <- matrix(c(1,2,3,4,5, 5,4,3,2,1), nrow = 2, byrow = TRUE) result <- apply_operations_batch_gpu(mat, c("1", "3"), k = 4) } # }
Run the code above in your browser using DataLab