powered by
Identifies states that appear in both tables by comparing V-columns. Used for finding intersections between forward and backward searches.
check_duplicates(df1, df2)
Data frame of duplicate states with a source column, or NULL if none
source
Data frame (first set of states)
Data frame (second set of states)
df1 <- data.frame(V1 = c(1, 2), V2 = c(2, 1)) df2 <- data.frame(V1 = c(2, 3), V2 = c(1, 2)) check_duplicates(df1, df2)
Run the code above in your browser using DataLab