Finds the state in a table that has the minimum Manhattan distance to a target state. If multiple states tie, selects the one with the smallest step number.
find_best_match_state(
target_state,
reachable_states,
method = "manhattan",
use_gpu = FALSE
)Single-row data frame of the best matching state
Integer vector, the target state
Data frame with V-columns