powered by
Searches a table of reachable states for the state whose celestial coordinates are closest to a target coordinate set.
find_closest_to_coords(reachable_states, target_coords, v_cols)
Single-row data frame of the closest state (with angular_distance column added)
Data frame with columns theta, phi, omega_conformal, and V-columns for state
List with component z (complex number)
z
Character vector of V-column names
# Typically used with output from get_reachable_states # find_closest_to_coords(states_df, target_coords, paste0("V", 1:n))
Run the code above in your browser using DataLab