powered by
Searches for a specific permutation state in a reachable states table and returns the first matching row with metadata.
find_combination_in_states(reachable_states_start, search_state)
Data frame row with state and metadata columns, or NULL if not found
Data frame with V-columns and metadata
Integer vector, the state to search for
df <- data.frame(V1 = c(1, 2), V2 = c(2, 1), operation = c("1", "2"), step = c(1, 2), combo_number = c(1, 1)) find_combination_in_states(df, c(2, 1))
Run the code above in your browser using DataLab